@@ -8,7 +8,7 @@
 // documentation
 #![doc = include_str!("../Readme.md")]
 pub mod command;
-mod errors;
+
 #[cfg(feature = "lsp")]
 mod language_server;
 pub mod nodes;
@@ -17,7 +17,6 @@ pub mod value;
 
 pub use self::{
     command::Command,
-    errors::{DiagnosticLevel, NoteError, NoteErrorKind, Result},
     nodes::{ASTKind, ASTNode, ASTNodes},
     value::Value,
 };
